package cn.wisenergy.chnmuseum.party.model;

import com.baomidou.mybatisplus.annotation.*;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.*;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotBlank;
import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * <p>
 * 展板
 * </p>
 *
 * @author Danny Lee
 * @since 2021-03-16
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@TableName("exhibition_board")
@ApiModel(value = "ExhibitionBoard对象", description = "展板")
public class ExhibitionBoard implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty("展板内容ID")
    @TableId(value = "id", type = IdType.ASSIGN_ID)
    private String id;

    @ApiModelProperty("展板分类名称")
    @TableField("name")
    @NotBlank(message = "展板分类名称不能为空")
    private String name;

    @ApiModelProperty("展板版权方ID")
    @TableField("board_copyright_owner_id")
    @NotBlank(message = "展板版权方ID不能为空")
    private String boardCopyrightOwnerId;

    @ApiModelProperty("展板分类ID")
    @TableField("exhibition_board_cat_id")
    @NotBlank(message = "展板分类ID不能为空")
    private String exhibitionBoardCatId;

    @ApiModelProperty("展板图片URL")
    @TableField("board_img_url")
    @NotBlank(message = "展板图片URL不能为空")
    private String boardImgUrl;

    @ApiModelProperty("展板二维码URL")
    @TableField("board_qrcode_url")
    @NotBlank(message = "展板二维码URL不能为空")
    private String boardQrcodeUrl;

    @ApiModelProperty("简介")
    @TableField("introduction")
    @NotBlank(message = "简介不能为空")
    private String introduction;

    @ApiModelProperty("视频版权方ID")
    @TableField("asset_copyright_owner_id")
    private String assetCopyrightOwnerId;

    @ApiModelProperty("视频类别ID")
    @TableField("asset_type")
    private String assetType;

    @ApiModelProperty("视频ID")
    @TableField("asset_id")
    private String assetId;

    @ApiModelProperty("导览音频URL")
    @TableField("guide_audio_url")
    private String guideAudioUrl;

    @ApiModelProperty("参考资料")
    @TableField("reference_material")
    private String referenceMaterial;

    @ApiModelProperty("创建日期")
    @TableField(value = "create_time", fill = FieldFill.INSERT)
    private LocalDateTime createTime;

    @ApiModelProperty("修改日期")
    @TableField(value = "update_time", fill = FieldFill.INSERT_UPDATE)
    private LocalDateTime updateTime;

    @ApiModelProperty("审核状态")
    @TableField("audit_status")
    private String auditStatus;

}
